@@ -33,10 +33,10 @@ class Taskframe(object):
     acceptable_params = [
         "classes",
         "tags",
-        "image_classes",
-        "image_tags",
-        "region_classes",
-        "region_tags",
+        "global_classes",
+        "global_tags",
+        "global_json_schema",
+        "global_ui_schema",
         "multiple",
         "files_accepted",
     ]
